#
# spec file for package python-pyalsaaudio
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pyalsaaudio
Version:        0.10.0
Release:        1.6
Summary:        ALSA bindings for Python
License:        Python-2.0
URL:            https://larsimmisch.github.io/pyalsaaudio/
Source:         https://files.pythonhosted.org/packages/source/p/pyalsaaudio/pyalsaaudio-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  alsa-devel
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
This package contains wrappers for accessing the ALSA API from Python.
It is fairly complete for PCM devices and Mixer access.

%prep
%setup -q -n pyalsaaudio-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch test.py -k 'not (testMixerAll or testMixerClose or testPCMAll or testPCMClose or testPCMDeprecated)'

%files %{python_files}
%license LICENSE
%doc doc/*.rst
%{python_sitearch}/*

%changelog
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.10.0:
  * support for periods in the PCM constructor.
  * new functions PCM.state(), PCM.drop() and PCM.drain()
  * improved underrun/overrun handling
  * documentation improvements/consolidation
  * more sampling rates
  * bug fixes
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.9.2
  Fix alsamixer_getvolume (#112 from @stephensp)
* Wed May  4 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.9.1:
  * Support decibel, percentage, and raw volumes in getvolume, setvolume,
    and getrange (#109 from @chrisdiamand):
- Use pytest for running the testsuite, and skip tests that require a
  sound card. Remove the bcond so the testsuite runs.
- Update docs shipped to be more documentation-like.
* Sat Mar 26 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.0:
  * 'getformats()' returns a dictionary of name / value pairs, one for each of the card's
    supported formats - e.g. '{"U8": 1, "S16_LE": 2}',
  * 'getchannels()' returns a list of the supported channel numbers, e.g. '[1, 2]',
  * 'getrates()' returns supported sample rates for the device, e.g. '[48000]',
  * 'getratebounds()' returns the device's official minimum and maximum supported
    sample rates as a tuple, e.g. '(4000, 48000)'.
  * Prevent hang on close after capturing audio
  * Return an empty string/bytestring when 'read()' detects an
    overrun. Previously the returned data was undefined
  * Unlimited setperiod buffer size when reading frames
* Wed Oct 18 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 0.8.4
  * See changelog at https://github.com/larsimmisch/pyalsaaudio/blob/0.8.4/CHANGES
* Mon Feb 13 2017 trcs@gmx.com
- specfile:
  * applied spec-cleaner
  * changed to https for source url
  * updated source url to files.pythonhosted.org
- splitted doc subpackage
- update to version 0.8.2:
  * fix #3 (we cannot get the revision from git for pip installs)
- changes from version 0.8.1:
  * document changes (this file)
- changes from version 0.8:
  * 'PCM()' has new 'device' and 'cardindex' keyword arguments.
    + The keyword 'device' allows to select virtual devices,
    'cardindex' can be used to select hardware cards by index (as
    with 'mixers()' and 'Mixer()').
    + The 'card' keyword argument is still supported, but deprecated.
    + The reason for this change is that the 'card' keyword argument
    guessed a device name from the card name, but this only works
    sometimes, and breaks opening virtual devices.
  * new function 'pcms()' to list available PCM devices.
  * mixers() and Mixer() take an additional 'device' keyword argument.
    This allows to list or open virtual devices.
  * The default behaviour of Mixer() without any arguments has
    changed.  Now Mixer() will try to open the 'default' Mixer instead
    of the Mixer that is associated with card 0.
  * fix a memory leak under Python 3.x
  * some more memory leaks in error conditions fixed.
* Sun Jan 13 2013 p.drouand@gmail.com
- Initial python3 support
* Fri Sep  2 2011 saschpe@suse.de
- Initial version
